@@ -5,5 +5,13 @@ from .click import ClickTool
 from .fill import FillTool
 from .type import TypeTool
 from .upload import UploadTool
+from .wait import WaitTool
 
-__all__ = ["NavigateTool", "ClickTool", "FillTool", "TypeTool", "UploadTool"]
+__all__ = [
+    "NavigateTool",
+    "ClickTool",
+    "FillTool",
+    "TypeTool",
+    "UploadTool",
+    "WaitTool",
+]
