@@ -2,16 +2,7 @@
 
 from typing import Optional, List, Any
 import google.generativeai as genai
-from ....llm import LLM, Tokenizer, Context
-
-# Model max token limits
-MODEL_MAX_TOKENS = {
-    "gemini-pro": 32768,
-    "gemini-1.5-pro": 2097152,  # 2M tokens
-    "gemini-1.5-flash": 1048576,  # 1M tokens
-    "gemini-2.0-flash": 1048576,  # 1M tokens
-    "gemini-2.5-flash": 1048576,  # 1M tokens
-}
+from ....llm import LLM, Context
 
 
 class GeminiLLM(LLM):
@@ -23,8 +14,6 @@ class GeminiLLM(LLM):
 
     def __init__(
         self,
-        tokenizer: Tokenizer,
-        max_tokens: int,
         model: genai.GenerativeModel,
         model_name: str,
         temperature: float,
@@ -33,13 +22,11 @@ class GeminiLLM(LLM):
         Initialize GeminiLLM (use create factory instead).
 
         Args:
-            tokenizer: Tokenizer for counting tokens
-            max_tokens: Maximum token limit for prompts
             model: Gemini GenerativeModel instance
             model_name: Model name
             temperature: Temperature for generation
         """
-        super().__init__(tokenizer, max_tokens)
+        super().__init__()
         self.model_name = model_name
         self.temperature = temperature
         self.model = model
@@ -50,16 +37,14 @@ class GeminiLLM(LLM):
         model: str = "gemini-2.5-flash",
         api_key: Optional[str] = None,
         temperature: float = 0.7,
-        max_tokens: Optional[int] = None,
-    ) -> 'GeminiLLM':
+    ) -> "GeminiLLM":
         """
-        Create a GeminiLLM instance with automatic tokenizer and max_tokens detection.
+        Create a GeminiLLM instance.
 
         Args:
             model: Model name (e.g., "gemini-2.5-flash", "gemini-1.5-pro")
             api_key: Google API key (if None, uses GOOGLE_API_KEY env var)
             temperature: Temperature for generation (0.0 to 2.0)
-            max_tokens: Override max tokens (if None, auto-detect from model)
 
         Returns:
             GeminiLLM instance
@@ -68,16 +53,6 @@ class GeminiLLM(LLM):
             >>> llm = GeminiLLM.create(model="gemini-2.5-flash")
             >>> response = await llm.generate("You are helpful", "Hello!")
         """
-        # Auto-create tokenizer for this model
-        from .gemini_tokenizer import GeminiTokenizer
-        tokenizer = GeminiTokenizer(model)
-
-        # Auto-detect max_tokens if not provided
-        if max_tokens is None:
-            max_tokens = MODEL_MAX_TOKENS.get(model)
-            if max_tokens is None:
-                raise ValueError(f"Unknown model: {model}. Please specify max_tokens manually.")
-
         # Configure API key
         if api_key:
             genai.configure(api_key=api_key)
@@ -87,10 +62,10 @@ class GeminiLLM(LLM):
             model_name=model,
             generation_config=genai.GenerationConfig(
                 temperature=temperature,
-            )
+            ),
         )
 
-        return cls(tokenizer, max_tokens, gemini_model, model, temperature)
+        return cls(gemini_model, model, temperature)
 
     def _build_content(self, context: Context) -> List[Any] | str:
         """Build content for Gemini API, supporting both text and images.
@@ -128,27 +103,41 @@ class GeminiLLM(LLM):
 
         return content
 
-    async def _generate(self, context: Context) -> str:
+    async def generate(self, context: Context, use_json: bool = False) -> str:
         """
-        Internal method for actual text generation using Gemini API.
+        Generate text using Gemini API.
 
-        Supports multimodal content (text + images).
+        Supports multimodal content (text + images) and JSON mode.
 
         Args:
             context: Context object with system, blocks (text + images), etc.
+            use_json: If True, force JSON output
 
         Returns:
             Generated text response from Gemini
         """
-        self.logger.info(f"Calling Gemini API - model: {self.model_name}, temperature: {self.temperature}")
+        self.logger.info(
+            f"Calling Gemini API - model: {self.model_name}, temperature: {self.temperature}, "
+            f"json_mode: {use_json}"
+        )
 
         # Build content (may include images)
         content = self._build_content(context)
 
-        response = await self.model.generate_content_async(content)
+        # Use JSON mode if requested
+        if use_json:
+            generation_config = genai.GenerationConfig(
+                temperature=self.temperature,
+                response_mime_type="application/json",
+            )
+            response = await self.model.generate_content_async(
+                content, generation_config=generation_config
+            )
+        else:
+            response = await self.model.generate_content_async(content)
 
         # Log token usage if available
-        if hasattr(response, 'usage_metadata') and response.usage_metadata:
+        if hasattr(response, "usage_metadata") and response.usage_metadata:
             self.logger.info(
                 f"Gemini API response - "
                 f"prompt_tokens: {response.usage_metadata.prompt_token_count}, "
